function onPageLoaded() {
    IDAL.getControlInterfaces()
        .then(onControlInterfaceAvailable);
}

function onControlInterfaceAvailable(iface) {
    console.log("Control interface available");

    // Disable default input contact management.
    // Input contacts will be managed by this app.
    // It is possible to do without it, but all input contact actions
    // defined by the engine will also be triggered.
    var config = {
        controller: "browser",
        lifetime: "url"
    };

    iface.contact.setInputConfiguration(config)
        .then(function(e) {
            console.log("Contact.setInputConfiguration(" + JSON.stringify(config) + ") => " + JSON.stringify(e));
        })
        .catch(function(e) {
            console.error("Error: Contact.setInputConfiguration(" + JSON.stringify(config) + ") => " + JSON.stringify(e));
        });

    var currentFolder = 0;		

    // Get events to retrieve current directory
    iface.player.addListener(function(event) {
        if (event.detail.type === 'folder-enter') {
            currentFolder = event.detail.folder.number;													
        }
    });

    iface.player.getFolderNumber().then(function(number) {
        currentFolder = number;
    });
	
    var fader = document.getElementById("fader");
	var chosenFolder = undefined;    
	var animating = false;    

    // Add listener for transition end events
    fader.addEventListener('transitionend', () => {
        animating = false;

        // Now that the screen is black, change the video.
        // Use stop() then play() to make safely remove the black layer without
        // displaying the old video...
        iface.player.stop()
            .then(function() {
                fader.classList.remove("fade-out");
				iface.contact.setOutputById(0, false);
                return iface.player.playFolder(chosenFolder);
            });
    });

    // Process input contact events
    window.addEventListener('idal-contact-event', function(e) {
        var detail = e.detail;		

        // Already in transition, do nothing
        if (animating) {
            return;
        }		
        chosenFolder = undefined;		
        switch (detail.name) {
            case "combined":				
				chosenFolder = 0;
				for (var i = detail.values.length - 1; i >= 0; i--) {
					chosenFolder = (chosenFolder * 256) + detail.values[i];
				}
				if ((chosenFolder !== 0) && (chosenFolder !== currentFolder)){
					animating = true;
                    fader.classList.add("fade-out");	
					iface.contact.setOutputById(0, true);
				}
                break;
            case "standalone":
				// Add code if need to use standalone input
				chosenFolder = 0;
				for (var i = detail.values.length - 1; i >= 0; i--) {
					chosenFolder = (chosenFolder * 256) + detail.values[i];
				}
				if ((chosenFolder !== 0) && (chosenFolder !== currentFolder)){
					animating = true;
                    fader.classList.add("fade-out");					
					iface.contact.setOutputById(0, true);
				}
                break;
        }
    });
}

window.addEventListener("load", onPageLoaded);
